==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAccessibleValueChangeEvent_shell.cpp <==
#include "QAccessibleValueChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleValueChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleValueChangeEvent")
    QAccessibleValueChangeEvent *_ptr = reinterpret_cast<QAccessibleValueChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleValueChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleValueChangeEvent_shell) ); }

jmethodID QAccessibleValueChangeEvent_shell::__shell_javaMethod(int pos) const { return QAccessibleValueChangeEvent_shell::__shell()->javaMethod(typeid(QAccessibleValueChangeEvent), pos); }

// emitting (writeShellConstructor)
QAccessibleValueChangeEvent_shell::QAccessibleValueChangeEvent_shell(QAccessibleInterface* iface0, const QVariant& val1)
    : QAccessibleValueChangeEvent(iface0, val1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent_shell(QAccessibleInterface* iface0, const QVariant& val1)", QAccessibleValueChangeEvent_shell::__shell())
    QAccessibleValueChangeEvent_shell::__shell()->constructed(typeid(QAccessibleValueChangeEvent));
}

QAccessibleValueChangeEvent_shell::QAccessibleValueChangeEvent_shell(QObject* obj0, const QVariant& val1)
    : QAccessibleValueChangeEvent(obj0, val1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent_shell(QObject* obj0, const QVariant& val1)", QAccessibleValueChangeEvent_shell::__shell())
    QAccessibleValueChangeEvent_shell::__shell()->constructed(typeid(QAccessibleValueChangeEvent));
}

// emitting (writeShellDestructor)
QAccessibleValueChangeEvent_shell::~QAccessibleValueChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleValueChangeEvent::~QAccessibleValueChangeEvent()", QAccessibleValueChangeEvent_shell::__shell())
    QAccessibleValueChangeEvent_shell::__shell()->destructed(typeid(QAccessibleValueChangeEvent));
}

void QAccessibleValueChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleValueChangeEvent_shell*>(ptr)->QAccessibleValueChangeEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleValueChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleValueChangeEvent_shell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleValueChangeEvent::", QAccessibleValueChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleValueChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface* >(__jni_env, __java_return_value);
                } else {
                    QAccessibleValueChangeEvent_shell::__shell()->warnForMethod("QAccessibleValueChangeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleValueChangeEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
void __qt_construct_QAccessibleValueChangeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface* >(__jni_env, iface0);
    jobject val1 = __java_arguments[1].l;
    QVariant  __qt_val1 = qtjambi_cast<QVariant >(__jni_env, val1);
    QAccessibleValueChangeEvent *__qt_this = new(__qtjambi_ptr) QAccessibleValueChangeEvent_shell(__qt_iface0, __qt_val1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QAccessibleValueChangeEvent(QObject*,QVariant)
void __qt_construct_QAccessibleValueChangeEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleValueChangeEvent(QObject*,QVariant)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject* >(__jni_env, obj0);
    jobject val1 = __java_arguments[1].l;
    QVariant  __qt_val1 = qtjambi_cast<QVariant >(__jni_env, val1);
    QAccessibleValueChangeEvent *__qt_this = new(__qtjambi_ptr) QAccessibleValueChangeEvent_shell(__qt_obj0, __qt_val1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QAccessibleValueChangeEvent_shell
void __qt_destruct_QAccessibleValueChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleValueChangeEvent")
    reinterpret_cast<QAccessibleValueChangeEvent_shell*>(ptr)->~QAccessibleValueChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleValueChangeEvent_2Lio_qt_gui_QAccessibleInterface_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jobject val1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = iface0;
        arguments[1].l = val1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleValueChangeEvent_0, sizeof(QAccessibleValueChangeEvent_shell), typeid(QAccessibleValueChangeEvent), true, &deleter_QAccessibleValueChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QObject*,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleValueChangeEvent_2Lio_qt_core_QObject_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jobject val1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QObject*,QVariant)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = obj0;
        arguments[1].l = val1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleValueChangeEvent_1, sizeof(QAccessibleValueChangeEvent_shell), typeid(QAccessibleValueChangeEvent), true, &deleter_QAccessibleValueChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleValueChangeEvent::setValue(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_setValue_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject val0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleValueChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleValueChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleValueChangeEvent::setValue(QVariant)", __qt_this)
        QVariant  __qt_val0 = qtjambi_cast<QVariant >(__jni_env, val0);
        __qt_this->setValue(__qt_val0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleValueChangeEvent::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleValueChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleValueChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleValueChangeEvent::value()const", __qt_this)
        QVariant __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleValueChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleValueChangeEvent>("QAccessibleValueChangeEvent", "io/qt/gui/QAccessibleValueChangeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleValueChangeEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleValueChangeEvent_0, "Lio/qt/gui/QAccessibleInterface;Ljava/lang/Object;")
       ,ConstructorInfo(&__qt_construct_QAccessibleValueChangeEvent_1, "Lio/qt/core/QObject;Ljava/lang/Object;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleValueChangeEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleValueChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleEvent, QAccessibleValueChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QAccessibleValueChangeEvent_shell.cpp <==
#include "QAccessibleValueChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleValueChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleValueChangeEvent")
    QAccessibleValueChangeEvent *_ptr = reinterpret_cast<QAccessibleValueChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleValueChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleValueChangeEvent_shell) ); }

jmethodID QAccessibleValueChangeEvent_oshell::__shell_javaMethod(int pos) const { return QAccessibleValueChangeEvent_shell::__shell()->javaMethod(typeid(QAccessibleValueChangeEvent), pos); }

// emitting (writeShellDestructor)
QAccessibleValueChangeEvent_shell::~QAccessibleValueChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleValueChangeEvent::~QAccessibleValueChangeEvent()", this)
    QAccessibleValueChangeEvent_shell::__shell()->destructed(typeid(QAccessibleValueChangeEvent));
}

// emitting (writeShellConstructor)
QAccessibleValueChangeEvent_shell::QAccessibleValueChangeEvent_shell(QAccessibleInterface* iface0, const QVariant& val1)
    : QAccessibleValueChangeEvent(iface0, val1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent_shell(QAccessibleInterface* iface0, const QVariant& val1)", this)
    QAccessibleValueChangeEvent_shell::__shell()->constructed(typeid(QAccessibleValueChangeEvent));
}

QAccessibleValueChangeEvent_shell::QAccessibleValueChangeEvent_shell(QObject* obj0, const QVariant& val1)
    : QAccessibleValueChangeEvent(obj0, val1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent_shell(QObject* obj0, const QVariant& val1)", this)
    QAccessibleValueChangeEvent_shell::__shell()->constructed(typeid(QAccessibleValueChangeEvent));
}

void QAccessibleValueChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleValueChangeEvent_shell*>(ptr)->QAccessibleValueChangeEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleValueChangeEvent));
}

void QAccessibleValueChangeEvent_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleValueChangeEvent_oshell*>(ptr)->QAccessibleValueChangeEvent_oshell::__shell()->tryDeleteShell(typeid(QAccessibleValueChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleValueChangeEvent_oshell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleValueChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface*>(__jni_env, __java_return_value);
                } else {
                    QAccessibleValueChangeEvent_shell::__shell()->warnForMethod("QAccessibleValueChangeEvent::accessibleInterface()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QAccessibleValueChangeEvent::accessibleInterface()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
void __qt_construct_QAccessibleValueChangeEvent_QAccessibleInterface_ptr_cref_QVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface*>(__jni_env, iface0);
    jobject val1 = __java_arguments[1].l;
    QVariant  __qt_val1 = qtjambi_cast<QVariant >(__jni_env, val1);
    QAccessibleValueChangeEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QAccessibleValueChangeEvent_oshell(__qt_iface0, __qt_val1);
    else
        __qt_this = new(__qtjambi_ptr) QAccessibleValueChangeEvent_shell(__qt_iface0, __qt_val1);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleValueChangeEvent_2Lio_qt_gui_QAccessibleInterface_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jobject val1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QAccessibleInterface*,QVariant)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = iface0;
        arguments[1].l = val1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleValueChangeEvent_QAccessibleInterface_ptr_cref_QVariant, sizeof(QAccessibleValueChangeEvent_shell), typeid(QAccessibleValueChangeEvent), 0, true, &deleter_QAccessibleValueChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QAccessibleValueChangeEvent(QObject*,QVariant)
void __qt_construct_QAccessibleValueChangeEvent_QObject_ptr_cref_QVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleValueChangeEvent(QObject*,QVariant)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject*>(__jni_env, obj0);
    jobject val1 = __java_arguments[1].l;
    QVariant  __qt_val1 = qtjambi_cast<QVariant >(__jni_env, val1);
    QAccessibleValueChangeEvent *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QAccessibleValueChangeEvent_oshell(__qt_obj0, __qt_val1);
    else
        __qt_this = new(__qtjambi_ptr) QAccessibleValueChangeEvent_shell(__qt_obj0, __qt_val1);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QObject*,QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleValueChangeEvent_2Lio_qt_core_QObject_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jobject val1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleValueChangeEvent::QAccessibleValueChangeEvent(QObject*,QVariant)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = obj0;
        arguments[1].l = val1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleValueChangeEvent_QObject_ptr_cref_QVariant, sizeof(QAccessibleValueChangeEvent_shell), typeid(QAccessibleValueChangeEvent), 0, true, &deleter_QAccessibleValueChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessibleValueChangeEvent_shell
void __qt_destruct_QAccessibleValueChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleValueChangeEvent")
    reinterpret_cast<QAccessibleValueChangeEvent_shell*>(ptr)->~QAccessibleValueChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleValueChangeEvent::setValue(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_setValue_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject val0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAccessibleValueChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleValueChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleValueChangeEvent::setValue(QVariant)", __this_nativeId)
        QVariant  __qt_val0 = qtjambi_cast<QVariant >(__jni_env, val0);
        __qt_this->setValue(__qt_val0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleValueChangeEvent::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleValueChangeEvent_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleValueChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleValueChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleValueChangeEvent::value()const", __this_nativeId)
        QVariant __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleValueChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleValueChangeEvent>("QAccessibleValueChangeEvent", "io/qt/gui/QAccessibleValueChangeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QAccessibleValueChangeEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleValueChangeEvent_QAccessibleInterface_ptr_cref_QVariant, "Lio/qt/gui/QAccessibleInterface;Ljava/lang/Object;")
       ,ConstructorInfo(&__qt_construct_QAccessibleValueChangeEvent_QObject_ptr_cref_QVariant, "Lio/qt/core/QObject;Ljava/lang/Object;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleValueChangeEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleValueChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleEvent, QAccessibleValueChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
